@@ -1,6 +1,7 @@
 from .classes import IsBool, IsStr, IsBytes, IsByteArray, IsSet, IsFrozenSet,\
     IsList, IsDict, IsTuple, IsRange, IsClass, IsFloat, IsInt, IsMemoryView, \
-    IsComplex, Guarantee, NumericGuarantee, TypeGuarantee, NoOp, IsNone, IsUnion
+    IsComplex, Guarantee, NumericGuarantee, TypeGuarantee, NoOp, IsNone, IsUnion, \
+    DynamicCheck
 from .decorator import add_guarantees, settings
 import pyguarantees.functional_guarantees.exceptions
 import pyguarantees.functional_guarantees.decorator.settings
