@@ -2,7 +2,7 @@ from dataclasses import dataclass
 
 from ._base import TypeGuarantee
 from pyguarantees.functional_guarantees.classes.util.common_checks import \
-    enforce_check_functions, check_type
+    enforce_dynamic_checks, check_type
 
 
 @dataclass
@@ -13,7 +13,7 @@ class IsBytes(TypeGuarantee):
 
     def enforce(self, arg) -> bytes:
         arg = check_type(arg, self)
-        enforce_check_functions(arg, self)
+        enforce_dynamic_checks(arg, self)
         return arg
 
 
@@ -25,7 +25,7 @@ class IsByteArray(TypeGuarantee):
 
     def enforce(self, arg) -> bytearray:
         arg = check_type(arg, self)
-        enforce_check_functions(arg, self)
+        enforce_dynamic_checks(arg, self)
         return arg
 
 
@@ -37,6 +37,6 @@ class IsMemoryView(TypeGuarantee):
 
     def enforce(self, arg) -> memoryview:
         arg = check_type(arg, self)
-        enforce_check_functions(arg, self)
+        enforce_dynamic_checks(arg, self)
         return arg
 
